@@ -2,6 +2,8 @@ from guizero import App, Box, Text
 
 app = App()
 box = Box(app, width=150, height=150)
-text = Text(box, text="hello")
-app.display()
+box.bg = "red"
+box.border = True
 
+text = Text(box, text="hello")
+app.display()
\ No newline at end of file
